Everyone knows how annoying it is that you can't simply import jupyter notebooks or functions from them into your code.
This is a simple and easy way to overcome this inconvenient reality.
Hope you have fun with it.
